LinuxWebViewEnvironmentCreationParams class
Object specifying creation parameters for creating a LinuxWebViewEnvironment.
Platform specific implementations can add additional fields by extending this class.
- Annotations
Constructors
- LinuxWebViewEnvironmentCreationParams({WebViewEnvironmentSettings? settings})
-
Creates a new LinuxWebViewEnvironmentCreationParams instance.
const
- LinuxWebViewEnvironmentCreationParams.fromPlatformWebViewEnvironmentCreationParams(PlatformWebViewEnvironmentCreationParams params)
-
Creates a LinuxWebViewEnvironmentCreationParams instance based on
PlatformWebViewEnvironmentCreationParams.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- settings → WebViewEnvironmentSettings?
-
WebView Environment settings.
finalinherited
Methods
-
isClassSupported(
{TargetPlatform? platform}) → bool -
Check if the current class is supported by the defaultTargetPlatform or a specific
platform.inherited -
isPropertySupported(
PlatformWebViewEnvironmentCreationParamsProperty property, {TargetPlatform? platform}) → bool -
Check if the given
propertyis supported by the defaultTargetPlatform or a specificplatform.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited